@@ -244,13 +244,13 @@ do_smooth_draw_focus(SmoothCanvas Canvas,
            SmoothInt height)
 {
 	gboolean free_dash_list = FALSE;
-	gint8 *dash_list = NULL;
+	gint8 *dash_list = "";
 
 	SmoothColor color;
 
 	SmoothLinePattern dash_pattern;  
 	SmoothInt line_width = 1;
-	SmoothBool interior_focus = FALSE;
+	SmoothBool interior_focus = TRUE;
 
 	/* Setup Pen Color, Line Pattern, & Width */
 	{
@@ -309,7 +309,7 @@ do_smooth_draw_focus(SmoothCanvas Canvas,
 
 		SmoothCanvasSetPenValues(Canvas, color, line_width, 
 						dash_pattern.Pattern[0] ? GDK_LINE_ON_OFF_DASH : GDK_LINE_SOLID,
-						GDK_JOIN_MITER, GDK_CAP_BUTT);
+						GDK_JOIN_MITER, GDK_CAP_NOT_LAST);
 	}
 
 	dash_pattern.Length = strlen(dash_pattern.Pattern);
@@ -317,7 +317,10 @@ do_smooth_draw_focus(SmoothCanvas Canvas,
 	if (dash_pattern.Pattern[0])
 		SmoothCanvasSetPenPattern(Canvas, dash_pattern);
 	
-	gtk_widget_get_focus_props (widget, NULL, NULL, &interior_focus);
+	if (widget)
+	{
+		gtk_widget_get_focus_props (widget, NULL, NULL, &interior_focus);
+	}
 
  	if (CHECK_DETAIL(detail, "button") && (is_in_combo_box (widget) && (ENTRY_BUTTON_EMBED(style))))
 	{
@@ -757,7 +760,8 @@ smooth_draw_spinbutton_stepper (SmoothCanvas Canvas,
    * more complicated because we can only do half for each stepper.
    */
 
-  GtkStateType parent_state = GTK_WIDGET_STATE(widget);
+  SmoothWidgetState parent_smooth_state = SMOOTH_STATE_DEFAULT;
+  GtkStateType parent_state = GTK_STATE_NORMAL;
   SmoothRectangle spin_area;
   smooth_part_style *part = NULL;
   SmoothInt thick = 2;
@@ -767,8 +771,11 @@ smooth_draw_spinbutton_stepper (SmoothCanvas Canvas,
 
   SmoothRectangleSetValues(&spin_area, x, y, width, height); 
 
-  if (parent_state != GTK_STATE_INSENSITIVE)
-    parent_state = GTK_STATE_NORMAL;
+  if (GTK_WIDGET_STATE(widget) == GTK_STATE_INSENSITIVE)
+  {
+	parent_smooth_state = SMOOTH_STATE_DISABLED;
+	parent_state = GTK_STATE_INSENSITIVE;
+  }
 
   part = THEME_PART(STEPPER_PART(style));
 
@@ -797,7 +804,7 @@ smooth_draw_spinbutton_stepper (SmoothCanvas Canvas,
 	{
           SmoothCanvasSetClipRectangle(Canvas, spin_area);
 
-          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[GDKSmoothWidgetState(parent_state)].Background));
+          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[parent_smooth_state].Background));
           SmoothCanvasFillRectangle(Canvas, x - thick, y + focus, width + thick - focus, height - focus*2);
 
           do_smooth_draw_shadow(Canvas, style, parent_state, GTK_SHADOW_IN, widget, "spinentry", 
@@ -824,7 +831,7 @@ smooth_draw_spinbutton_stepper (SmoothCanvas Canvas,
 	{
           SmoothCanvasSetClipRectangle(Canvas, spin_area);
 
-          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[GDKSmoothWidgetState(parent_state)].Background));
+          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[parent_smooth_state].Background));
           SmoothCanvasFillRectangle(Canvas, x - thick, y, width + thick - focus, height - focus);
 
           do_smooth_draw_shadow(Canvas, style, parent_state, GTK_SHADOW_IN, widget, "spinentry", 
@@ -854,7 +861,7 @@ smooth_draw_spinbutton_stepper (SmoothCanvas Canvas,
 	{
           SmoothCanvasSetClipRectangle(Canvas, spin_area);
 
-          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[GDKSmoothWidgetState(parent_state)].Background));
+          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[parent_smooth_state].Background));
           SmoothCanvasFillRectangle(Canvas, x + focus, y + focus, width + thick*2 - focus, height - focus);
 
           do_smooth_draw_shadow(Canvas, style, parent_state, GTK_SHADOW_IN, widget, "spinentry", 
@@ -881,7 +888,7 @@ smooth_draw_spinbutton_stepper (SmoothCanvas Canvas,
 	{
           SmoothCanvasSetClipRectangle(Canvas, spin_area);
 
-          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[GDKSmoothWidgetState(parent_state)].Background));
+          SmoothCanvasSetPenColor(Canvas, (COLOR_CUBE(style).Input[parent_smooth_state].Background));
           SmoothCanvasFillRectangle(Canvas, x + focus, y, width + thick*2 - focus, height - focus);
 
           do_smooth_draw_shadow(Canvas, style, parent_state, GTK_SHADOW_IN, widget, "spinentry", 
@@ -963,7 +970,6 @@ do_smooth_draw_box(SmoothCanvas Canvas,
     } else if (CHECK_DETAIL(detail, "trough")) {
         if (GTK_IS_SCALE (widget) && REAL_SLIDERS(style)) {
 		SmoothLineBevel line_bevel;
-		SmoothColor base;
 
 	  if (!part) part = THEME_PART(BACKGROUND_PART(style));
 
@@ -1788,7 +1794,8 @@ smooth_draw_box(GtkStyle * style,
 		smooth_part_style *part = NULL;
 		SmoothDouble roundness = 0.0;
 
-		fill =  COLOR_CUBE(style).Input[GDKSmoothWidgetState(state_type)].Background;	
+		fill =  COLOR_CUBE(style).Input[GDKSmoothWidgetState(state_type)].Background;
+		base =  COLOR_CUBE(style).Interaction[GDKSmoothWidgetState(state_type)].Background;
 
 		GDKInitializeCanvas(&da, style, window, area, NULL, NULL, width, height, 0, 0, &COLOR_CUBE(style));
 
@@ -2487,248 +2494,15 @@ smooth_draw_resize_grip (GtkStyle       *style,
                               gint            width,
                               gint            height)
 {
-  g_return_if_fail (GTK_IS_STYLE (style));
-  g_return_if_fail (window != NULL);
+	g_return_if_fail(sanitize_parameters(style, window, &width, &height));
   
-  if (widget && GTK_IS_STATUSBAR(widget) && !RESIZE_GRIP(style)) {
-    gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(widget), FALSE);
-    return;
-  }
- 
+	if (widget && GTK_IS_STATUSBAR(widget) && !RESIZE_GRIP(style)) 
+	{
+		//gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(widget), FALSE);
+		return;
+	}
 
-   
-  if (area)
-    {
-      gdk_gc_set_clip_rectangle (style->light_gc[state_type], area);
-      gdk_gc_set_clip_rectangle (style->dark_gc[state_type], area);
-      gdk_gc_set_clip_rectangle (style->bg_gc[state_type], area);
-    }
-  
-  switch (edge)
-    {
-    case GDK_WINDOW_EDGE_WEST:
-    case GDK_WINDOW_EDGE_EAST:
-      {
-	gint xi;
-
-        if (edge==GDK_WINDOW_EDGE_WEST) 
-          make_square(&height, &width); 
-        else 
-          make_square_offset(&height, &width, &x);
-	
-	xi = x;
-
-	while (xi < x + width)
-	  {
-	    gdk_draw_line (window,
-			   style->light_gc[state_type],
-			   xi, y,
-			   xi, y + height);
-
-	    xi++;
-	    gdk_draw_line (window,
-			   style->dark_gc[state_type],
-			   xi, y,
-			   xi, y + height);
-
-	    xi += 2;
-	  }
-      }
-      break;
-    case GDK_WINDOW_EDGE_NORTH:
-    case GDK_WINDOW_EDGE_SOUTH:
-      {
-	gint yi;
-
-        if (edge==GDK_WINDOW_EDGE_NORTH) 
-          make_square(&width, &height); 
-        else 
-          make_square_offset(&width, &height, &y);
-
-	yi = y;
-
-	while (yi < y + height)
-	  {
-	    gdk_draw_line (window,
-			   style->light_gc[state_type],
-			   x, yi,
-			   x + width, yi);
-
-	    yi++;
-	    gdk_draw_line (window,
-			   style->dark_gc[state_type],
-			   x, yi,
-			   x + width, yi);
-
-	    yi+= 2;
-	  }
-      }
-      break;
-    case GDK_WINDOW_EDGE_NORTH_WEST:
-      {
-	gint xi, yi;
-
-        make_square(&width, &height);
-        make_square(&height, &width);
-	
-	xi = x + width;
-	yi = y + height;
-
-	while (xi > x + 3)
-	  {
-	    gdk_draw_line (window,
-			   style->dark_gc[state_type],
-			   xi, y,
-			   x, yi);
-
-	    --xi;
-	    --yi;
-
-	    gdk_draw_line (window,
-			   style->dark_gc[state_type],
-			   xi, y,
-			   x, yi);
-
-	    --xi;
-	    --yi;
-
-	    gdk_draw_line (window,
-			   style->light_gc[state_type],
-			   xi, y,
-			   x, yi);
-
-	    xi -= 3;
-	    yi -= 3;
-	    
-	  }
-      }
-      break;
-    case GDK_WINDOW_EDGE_NORTH_EAST:
-      {
-        gint xi, yi;
-
-        make_square(&width, &height);
-        make_square_offset(&height, &width, &x);
-
-        xi = x;
-        yi = y + height;
-
-        while (xi < (x + width - 3))
-          {
-            gdk_draw_line (window,
-                           style->light_gc[state_type],
-                           xi, y,
-                           x + width, yi);                           
-
-            ++xi;
-            --yi;
-            
-            gdk_draw_line (window,
-                           style->dark_gc[state_type],
-                           xi, y,
-                           x + width, yi);                           
-
-            ++xi;
-            --yi;
-            
-            gdk_draw_line (window,
-                           style->dark_gc[state_type],
-                           xi, y,
-                           x + width, yi);
-
-            xi += 3;
-            yi -= 3;
-          }
-      }
-      break;
-    case GDK_WINDOW_EDGE_SOUTH_WEST:
-      {
-	gint xi, yi;
-
-        make_square_offset(&width, &height, &y);
-        make_square(&height, &width);
-	
-	xi = x + width;
-	yi = y;
-
-	while (xi > x + 3)
-	  {
-	    gdk_draw_line (window,
-			   style->dark_gc[state_type],
-			   x, yi,
-			   xi, y + height);
-
-	    --xi;
-	    ++yi;
-
-	    gdk_draw_line (window,
-			   style->dark_gc[state_type],
-			   x, yi,
-			   xi, y + height);
-
-	    --xi;
-	    ++yi;
-
-	    gdk_draw_line (window,
-			   style->light_gc[state_type],
-			   x, yi,
-			   xi, y + height);
-
-	    xi -= 3;
-	    yi += 3;
-	    
-	  }
-      }
-      break;
-    case GDK_WINDOW_EDGE_SOUTH_EAST:
-      {
-        gint xi, yi;
-
-        make_square_offset(&width, &height, &y);
-        make_square_offset(&height, &width, &x);
-     
-        xi = x;
-        yi = y;
-
-        while (xi < (x + width - 3))
-          {
-            gdk_draw_line (window,
-                           style->light_gc[state_type],
-                           xi, y + height,
-                           x + width, yi);                           
-
-            ++xi;
-            ++yi;
-            
-            gdk_draw_line (window,
-                           style->dark_gc[state_type],
-                           xi, y + height,
-                           x + width, yi);                           
-
-            ++xi;
-            ++yi;
-            
-            gdk_draw_line (window,
-                           style->dark_gc[state_type],
-                           xi, y + height,
-                           x + width, yi);
-
-            xi += 3;
-            yi += 3;
-          }
-      }
-      break;
-    default:
-      return;
-      break;
-    }
-  
-  if (area)
-    {
-      gdk_gc_set_clip_rectangle (style->light_gc[state_type], NULL);
-      gdk_gc_set_clip_rectangle (style->dark_gc[state_type], NULL);
-      gdk_gc_set_clip_rectangle (style->bg_gc[state_type], NULL);
-    }
+	smooth_theme_parent_class->draw_resize_grip (style, window, state_type, area, widget, detail, edge, x, y, width, height);
 }
 
 void
@@ -2761,16 +2535,14 @@ smooth_draw_flat_box (GtkStyle * style,
 
    g_return_if_fail(sanitize_parameters(style, window, &width, &height));
 
-
-
    /* we always want call to the default for treeviews and such */  
  
    if ((CHECK_DETAIL(detail, "text")) || (CHECK_DETAIL(detail, "viewportbin")) || (CHECK_DETAIL(detail, "entry_bg")) || ((CHECK_DETAIL(detail, "cell_even")) || 
       (CHECK_DETAIL(detail, "cell_odd")) || (CHECK_DETAIL(detail, "cell_even_ruled")) || (CHECK_DETAIL(detail, "cell_odd_ruled")) || (CHECK_DETAIL(detail, "cell_even_sorted")) ||
       (CHECK_DETAIL(detail, "cell_odd_sorted")) || (CHECK_DETAIL(detail, "cell_even_ruled_sorted")) || (CHECK_DETAIL(detail, "cell_odd_ruled_sorted"))))
    {
-     parent_class->draw_flat_box (style, window, state_type, shadow_type,
-			          area, widget, detail, x, y, width, height);
+     smooth_theme_parent_class->draw_flat_box (style, window, state_type, shadow_type,
+                                               area, widget, detail, x, y, width, height);
    } 
    else {
         GDKInitializeCanvas(&da, style, window, area, NULL, NULL, width, height, 0, 0,&COLOR_CUBE(style));
